# octopus-ml

Set of handy ML and data tools - from data exploration, visualization, pre-processing, hyper parameter tuning, modeling and all the way to final Ml model evaluation 
![Image](/images/octopus_know_your_data.png)
